==> _private_core_network-1.2.25.tar.gz: lib/network_resources/model/dashboard_info.dart <==
class DashboardConfig {
  DashboardConfig1? dashboardConfig;
  UserProConfig? userProConfig;
  DashboardTheme? dashboardTheme;

  DashboardConfig(
      {this.dashboardConfig, this.userProConfig, this.dashboardTheme});

  DashboardConfig.fromJson(Map<String, dynamic> json) {
    if (json["dashboardConfig"] is Map) {
      dashboardConfig = DashboardConfig1.fromJson(json["dashboardConfig"]);
    }
    if (json["UserProConfig"] is Map) {
      userProConfig = UserProConfig.fromJson(json["UserProConfig"]);
    }
    if (json["dashboardTheme"] is Map) {
      dashboardTheme = DashboardTheme.fromJson(json["dashboardTheme"]);
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    if (dashboardConfig != null) {
      _data["dashboardConfig"] = dashboardConfig?.toJson();
    }
    if (userProConfig != null) {
      _data["UserProConfig"] = userProConfig?.toJson();
    }
    if (dashboardTheme != null) {
      _data["dashboardTheme"] = dashboardTheme?.toJson();
    }
    return _data;
  }
}

class UserProConfig {
  List<dynamic>? modules;
  List<dynamic>? submodules;
  List<dynamic>? features;

  UserProConfig({this.modules, this.submodules, this.features});

  UserProConfig.fromJson(Map<String, dynamic> json) {
    if (json["modules"] is List) {
      modules = json["modules"] ?? [];
    }
    if (json["submodules"] is List) {
      submodules = json["submodules"] ?? [];
    }
    if (json["features"] is List) {
      features = json["features"] ?? [];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    if (modules != null) {
      _data["modules"] = modules;
    }
    if (submodules != null) {
      _data["submodules"] = submodules;
    }
    if (features != null) {
      _data["features"] = features;
    }
    return _data;
  }
}

class DashboardConfig1 {
  _Version? version;

  DashboardConfig1({this.version});

  DashboardConfig1.fromJson(Map<String, dynamic> json) {
    if (json["version"] is Map) {
      version = _Version.fromJson(json["version"]);
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    if (version != null) {
      _data["version"] = version?.toJson();
    }
    return _data;
  }
}

class _Version {
  String? label;
  dynamic updatedAt;
  String? uniqueIdentifier;
  int? id;
  String? dashboardRef;
  List<Modules>? modules;

  _Version(
      {this.label,
      this.updatedAt,
      this.uniqueIdentifier,
      this.id,
      this.dashboardRef,
      this.modules});

  _Version.fromJson(Map<String, dynamic> json) {
    if (json["label"] is String) {
      label = json["label"];
    }
    updatedAt = json["updatedAt"];
    if (json["uniqueIdentifier"] is String) {
      uniqueIdentifier = json["uniqueIdentifier"];
    }
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["dashboardRef"] is String) {
      dashboardRef = json["dashboardRef"];
    }
    if (json["modules"] is List) {
      modules = json["modules"] == null
          ? null
          : (json["modules"] as List).map((e) => Modules.fromJson(e)).toList();
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["label"] = label;
    _data["updatedAt"] = updatedAt;
    _data["uniqueIdentifier"] = uniqueIdentifier;
    _data["id"] = id;
    _data["dashboardRef"] = dashboardRef;
    if (modules != null) {
      _data["modules"] = modules?.map((e) => e.toJson()).toList();
    }
    return _data;
  }
}

class Modules {
  int? id;
  String? label;
  dynamic productRefId;
  String? uniqueIdentifier;
  int? menuId;
  String? menuLabel;
  int? index;
  List<Submodule>? submodels;

  Modules(
      {this.id,
      this.label,
      this.productRefId,
      this.uniqueIdentifier,
      this.menuId,
      this.menuLabel,
      this.index,
      this.submodels});

  Modules.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["label"] is String) {
      label = json["label"];
    }
    productRefId = json["productRefId"];
    if (json["uniqueIdentifier"] is String) {
      uniqueIdentifier = json["uniqueIdentifier"];
    }
    if (json["menuId"] is int) {
      menuId = json["menuId"];
    }
    if (json["menuLabel"] is String) {
      menuLabel = json["menuLabel"];
    }
    if (json["index"] is int) {
      index = json["index"];
    }
    if (json["submodels"] is List) {
      submodels = json["submodels"] == null
          ? null
          : (json["submodels"] as List)
              .map((e) => Submodule.fromJson(e))
              .toList();
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["label"] = label;
    _data["productRefId"] = productRefId;
    _data["uniqueIdentifier"] = uniqueIdentifier;
    _data["menuId"] = menuId;
    _data["menuLabel"] = menuLabel;
    _data["index"] = index;
    if (submodels != null) {
      _data["submodels"] = submodels?.map((e) => e.toJson()).toList();
    }
    return _data;
  }
}

class Submodule {
  int? id;
  String? label;
  dynamic productRefId;
  String? uniqueIdentifier;
  List<Features>? features;

  Submodule(
      {this.id,
      this.label,
      this.productRefId,
      this.uniqueIdentifier,
      this.features});

  Submodule.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["label"] is String) {
      label = json["label"];
    }
    productRefId = json["productRefId"];
    if (json["uniqueIdentifier"] is String) {
      uniqueIdentifier = json["uniqueIdentifier"];
    }
    if (json["features"] is List) {
      features = json["features"] == null
          ? null
          : (json["features"] as List)
              .map((e) => Features.fromJson(e))
              .toList();
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["label"] = label;
    _data["productRefId"] = productRefId;
    _data["uniqueIdentifier"] = uniqueIdentifier;
    if (features != null) {
      _data["features"] = features?.map((e) => e.toJson()).toList();
    }
    return _data;
  }
}

class Features {
  int? id;
  String? featureRef;
  String? label;
  String? uniqueIdentifier;

  Features({this.id, this.featureRef, this.label, this.uniqueIdentifier});

  Features.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["featureRef"] is String) {
      featureRef = json["featureRef"];
    }
    if (json["label"] is String) {
      label = json["label"];
    }
    if (json["uniqueIdentifier"] is String) {
      uniqueIdentifier = json["uniqueIdentifier"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["featureRef"] = featureRef;
    _data["label"] = label;
    _data["uniqueIdentifier"] = uniqueIdentifier;
    return _data;
  }
}

class DashboardTheme {
  int? id;
  String? label;

  DashboardTheme({
    this.id,
    this.label,
  });

  DashboardTheme.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["label"] is String) {
      label = json["label"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["label"] = label;
    return _data;
  }
}

==> _private_core_network-1.3.48.tar.gz: lib/network_resources/model/dashboard_info.dart <==
class DashboardConfig {
  DashboardConfig1? dashboardConfig;
  UserProConfig? userProConfig;
  DashboardTheme? dashboardTheme;

  DashboardConfig(
      {this.dashboardConfig, this.userProConfig, this.dashboardTheme});

  DashboardConfig.fromJson(Map<String, dynamic> json) {
    if (json["dashboardConfig"] is Map) {
      dashboardConfig = DashboardConfig1.fromJson(json["dashboardConfig"]);
    }
    if (json["UserProConfig"] is Map) {
      userProConfig = UserProConfig.fromJson(json["UserProConfig"]);
    }
    if (json["dashboardTheme"] is Map) {
      dashboardTheme = DashboardTheme.fromJson(json["dashboardTheme"]);
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    if (dashboardConfig != null) {
      data["dashboardConfig"] = dashboardConfig?.toJson();
    }
    if (userProConfig != null) {
      data["UserProConfig"] = userProConfig?.toJson();
    }
    if (dashboardTheme != null) {
      data["dashboardTheme"] = dashboardTheme?.toJson();
    }
    return data;
  }
}

class UserProConfig {
  List<dynamic>? modules;
  List<dynamic>? submodules;
  List<dynamic>? features;

  UserProConfig({this.modules, this.submodules, this.features});

  UserProConfig.fromJson(Map<String, dynamic> json) {
    if (json["modules"] is List) {
      modules = json["modules"] ?? [];
    }
    if (json["submodules"] is List) {
      submodules = json["submodules"] ?? [];
    }
    if (json["features"] is List) {
      features = json["features"] ?? [];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    if (modules != null) {
      data["modules"] = modules;
    }
    if (submodules != null) {
      data["submodules"] = submodules;
    }
    if (features != null) {
      data["features"] = features;
    }
    return data;
  }
}

class DashboardConfig1 {
  _Version? version;

  DashboardConfig1({this.version});

  DashboardConfig1.fromJson(Map<String, dynamic> json) {
    if (json["version"] is Map) {
      version = _Version.fromJson(json["version"]);
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    if (version != null) {
      data["version"] = version?.toJson();
    }
    return data;
  }
}

class _Version {
  String? label;
  dynamic updatedAt;
  String? uniqueIdentifier;
  int? id;
  String? dashboardRef;
  List<Modules>? modules;

  _Version();

  _Version.fromJson(Map<String, dynamic> json) {
    if (json["label"] is String) {
      label = json["label"];
    }
    updatedAt = json["updatedAt"];
    if (json["uniqueIdentifier"] is String) {
      uniqueIdentifier = json["uniqueIdentifier"];
    }
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["dashboardRef"] is String) {
      dashboardRef = json["dashboardRef"];
    }
    if (json["modules"] is List) {
      modules = json["modules"] == null
          ? null
          : (json["modules"] as List).map((e) => Modules.fromJson(e)).toList();
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["label"] = label;
    data["updatedAt"] = updatedAt;
    data["uniqueIdentifier"] = uniqueIdentifier;
    data["id"] = id;
    data["dashboardRef"] = dashboardRef;
    if (modules != null) {
      data["modules"] = modules?.map((e) => e.toJson()).toList();
    }
    return data;
  }
}

class Modules {
  int? id;
  String? label;
  dynamic productRefId;
  String? uniqueIdentifier;
  int? menuId;
  String? menuLabel;
  int? index;
  List<Submodule>? submodels;

  Modules(
      {this.id,
      this.label,
      this.productRefId,
      this.uniqueIdentifier,
      this.menuId,
      this.menuLabel,
      this.index,
      this.submodels});

  Modules.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["label"] is String) {
      label = json["label"];
    }
    productRefId = json["productRefId"];
    if (json["uniqueIdentifier"] is String) {
      uniqueIdentifier = json["uniqueIdentifier"];
    }
    if (json["menuId"] is int) {
      menuId = json["menuId"];
    }
    if (json["menuLabel"] is String) {
      menuLabel = json["menuLabel"];
    }
    if (json["index"] is int) {
      index = json["index"];
    }
    if (json["submodels"] is List) {
      submodels = json["submodels"] == null
          ? null
          : (json["submodels"] as List)
              .map((e) => Submodule.fromJson(e))
              .toList();
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["label"] = label;
    data["productRefId"] = productRefId;
    data["uniqueIdentifier"] = uniqueIdentifier;
    data["menuId"] = menuId;
    data["menuLabel"] = menuLabel;
    data["index"] = index;
    if (submodels != null) {
      data["submodels"] = submodels?.map((e) => e.toJson()).toList();
    }
    return data;
  }
}

class Submodule {
  int? id;
  String? label;
  dynamic productRefId;
  String? uniqueIdentifier;
  List<Features>? features;

  Submodule(
      {this.id,
      this.label,
      this.productRefId,
      this.uniqueIdentifier,
      this.features});

  Submodule.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["label"] is String) {
      label = json["label"];
    }
    productRefId = json["productRefId"];
    if (json["uniqueIdentifier"] is String) {
      uniqueIdentifier = json["uniqueIdentifier"];
    }
    if (json["features"] is List) {
      features = json["features"] == null
          ? null
          : (json["features"] as List)
              .map((e) => Features.fromJson(e))
              .toList();
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["label"] = label;
    data["productRefId"] = productRefId;
    data["uniqueIdentifier"] = uniqueIdentifier;
    if (features != null) {
      data["features"] = features?.map((e) => e.toJson()).toList();
    }
    return data;
  }
}

class Features {
  int? id;
  String? featureRef;
  String? label;
  String? uniqueIdentifier;

  Features({this.id, this.featureRef, this.label, this.uniqueIdentifier});

  Features.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["featureRef"] is String) {
      featureRef = json["featureRef"];
    }
    if (json["label"] is String) {
      label = json["label"];
    }
    if (json["uniqueIdentifier"] is String) {
      uniqueIdentifier = json["uniqueIdentifier"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["featureRef"] = featureRef;
    data["label"] = label;
    data["uniqueIdentifier"] = uniqueIdentifier;
    return data;
  }
}

class DashboardTheme {
  int? id;
  String? label;

  DashboardTheme({
    this.id,
    this.label,
  });

  DashboardTheme.fromJson(Map<String, dynamic> json) {
    if (json["id"] is int) {
      id = json["id"];
    }
    if (json["label"] is String) {
      label = json["label"];
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["label"] = label;
    return data;
  }
}
